{ nix-flatpak, lib, pkgs, ... }:
{
  nixpkgs.config.allowUnfree = true;
  home = {
    packages = with pkgs; [
      gnupg
      eza
      just
      fd
      fzf
      bat
      jq
      yt-dlp
      htop
      ripgrep
      erdtree

      pciutils
      util-linux
      coreutils
      libgcc
      raylib
      SDL2

      ruby
      janet
      jpm
      python3
      sbcl
      nodejs_18
      platformio-core

      kanata-with-cmd
      wezterm 
      emacs
      fish
      starship
      lazygit
      nnn
      
      bitwarden-cli
      bitwarden-desktop
      tailscale

      gnomeExtensions.just-perfection
      gnomeExtensions.dash-to-dock
      gnomeExtensions.pano
      gnome.gnome-software
      gnome.gnome-tweaks

      albert
      obsidian
      vlc
      polychromatic
      discord
      slack
      signal-desktop
      libreoffice
      plexamp
      audacity
      supercollider-with-plugins
      bitwig-studio
      blender
      davinci-resolve-studio
      steam
      zotero_7
    ];

    username = "emenel";
    homeDirectory = "/home/emenel";

    stateVersion = "24.05";
  };
  
  programs = {
    home-manager.enable = true;
    direnv = {
      enable = true;
      #enableFishIntegration = true; # see note on other shells below
      nix-direnv.enable = true;
    };
    fish.enable = true;
    starship = {
      enable = true;
      enableFishIntegration = true;
    };
  };

  services.flatpak.enable = true;

  xdg.systemDirs.data = [
    "/home/emenel/.local/share/applications"
    "/var/lib/flatpak/exports/share"
    "/home/emenel/.local/share/flatpak/exports/share"
    "/home/emenel/.nix-profile/share/applications"
  ];

  services.flatpak.packages = [
    "io.github.zen_browser.zen"
  ];

  xdg.configFile."wezterm".source = ../dotfiles/dot_config/wezterm;
  #xdg.configFile."fish".source = ./
}
